Effectuer une évaluation des risques avec l’OiRA | OiRA

Thèmes

# Effectuer une évaluation des risques avec l’OiRA

## Démarrer une nouvelle session

Pour commencer une nouvelle évaluation des risques, cliquez sur le lien «Démarrer une nouvelle session».

## Ouvrir une évaluation des risques

Après avoir démarré une évaluation des risques, vous pouvez la retrouver à tout moment dans le tableau de bord sous la rubrique «Mes évaluations des risques». À partir de là, vous pouvez également démarrer une nouvelle évaluation des risques.

Le tableau de bord.

## Parcourir les étapes d’une évaluation des risques

Chaque évaluation des risques vous guide à travers plusieurs étapes. Elles s’affichent dans le menu principal sur le côté gauche de l’écran:

- Préparation
- Participation
- Identification + Estimation
- Plan d’action
- Rapport
- Statut.

La structure de chaque outil peut varier selon les choix arrêtés par les partenaires nationaux/développeurs d’outils OiRA. Dans certains outils, l’étape d’identification et d’estimation des risques englobe le plan d’action. Dans ce cas, le menu suivant s’affiche sur la partie gauche de l’écran:

- Préparation
- Participation
- Évaluation
- Rapport
- Statut

## Préparation

«Préparation» est le point de départ de chaque session/outil. Vous commencez par donner un nom à l’évaluation des risques, lequel vous permettra plus tard de bien distinguer les différentes évaluations des risques que vous avez effectuées avec l’outil.

Le lien «En savoir plus sur cet outil…» fournit de plus amples informations sur l’outil sélectionné et les parties impliquées dans son développement.

Après avoir cliqué sur «Démarrer», des questions supplémentaires peuvent s’afficher, en fonction de l’outil que vous utilisez. Cet écran préliminaire avec des «questions sur le profil» n’apparaît qu’avec les outils qui offrent cette option.

Ici, vous pouvez:

- sélectionner ou non la ou les situation(s) en fonction de leur pertinence pour votre activité professionnelle. Choisissez «oui» s’il y a lieu.
- énumérer plusieurs unités commerciales, succursales ou magasins, etc. Les risques associés seront répétés pour chaque entrée.

L'écran «Profil» à l'étape «Préparation

L’étape de préparation est très importante car elle permet de définir avec précision le type d’activité et les risques associés auxquels votre entreprise est exposée. Après avoir cliqué sur «Enregistrer et continuer», vous serez dirigé vers la section suivante, «Participation».

Remarque: De nombreux outils ne comportent pas de questions sur le profil car ils n’utilisent pas cette fonction pour cibler l’outil. Dans ce cas, l’outil saute automatiquement cet écran.

## Participation

Cette étape viser à rappeler l’importance de la participation des travailleurs et présente différentes façons d’assurer une bonne participation des travailleurs. Ici, vous pouvez télécharger ou imprimer le contenu de l’évaluation des risques pour le partager avec vos travailleurs/employés. Les travailleurs sont ainsi en mesure d’apporter leur contribution à l’évaluation de la situation sur leur lieu de travail.

## Estimation

À cette étape, vous identifierez les risques et les problèmes qui concernent votre entreprise.

Remarque: Selon les choix posés par les partenaires OiRA concernant la configuration de l’outil, l’étape «Plan d’action» (voir ci-dessous) peut être intégrée dans cet écran. Dans ce cas, l’étape dans son ensemble est appelée «Évaluation», et les éléments décrits dans le «Plan d’action» apparaissent sous l’identification et l’estimation de chaque risque.

Identification et Estimation.

À gauche de l’écran, au-dessous de la rubrique «Identification + Estimation»/«Évaluation», vous pouvez voir chacun des modules/rubriques inclus dans l’outil. La rubrique que vous consultez apparaît en surbrillance.

### Identification

Pour chaque risque, vous devez décider si l’énoncé qui décrit un état désiré, s’applique à votre entreprise. Vous pouvez répondre de la façon suivante:

- Oui: si vous répondez par «oui», aucune autre action n’est nécessaire, car vous avez estimé que le risque n’était pas présent.
- Non: si vous répondez par «non», des mesures doivent être prises. Vous serez invité à décider des mesures particulières à prendre.
- Sans objet: certains énoncés de risque donnent la possibilité de sélectionner «sans objet» si le risque n’est pas pertinent pour votre entreprise/établissement.

Vous trouverez généralement plus d’informations sur le risque en question au-dessous de chaque énoncé.

- Information: une brève description, parfois accompagnée d’images, fournissant plus de détails sur le risque.
- Ressources: des informations supplémentaires sur le risque, telles que des références juridiques et politiques. Parfois, vous pouvez également trouver des documents en annexe pour un examen plus approfondi.
- Commentaires: vous pouvez ajouter ici vos propres commentaires, qui figureront dans votre rapport à la fin de l’évaluation.

Une fois que vous aurez donné votre réponse pour chaque énoncé de risque, le menu de gauche sera mis à jour avec un symbole en couleur indiquant votre réponse:

- réponse positive (coche verte)
- réponse négative (croix rouge)
- report (point d’interrogation orange)

Lorsqu’aucune réponse n’a été donnée, le symbole gris reste en place.

### Estimation

À cette étape, vous évaluez la priorité d’un risque que vous avez identifié.

Évaluer un risque.

Remarque: L’évaluation ne figure pas dans certains outils OiRA. Cela dépend de la configuration choisie par le partenaire national/développeur de l’outil OiRA.

Si vous avez identifié un risque comme étant présent (indiqué par une croix rouge), la section Estimation apparaît. En fonction de la méthode d’évaluation établie pour chaque risque, il vous sera demandé:

- d’estimer la priorité : élevée, moyenne ou faible

Définir la priorité d'un risque.

OU

- de répondre à quelques questions sur la fréquence, la gravité et la probabilité du risque, afin que le niveau de priorité puisse être établi en fonction de vos réponses.

Définir les variables d'un risque.

### Risques prioritaires fixés par le secteur:

Certains risques sont considérés comme très importants par le partenaire national/développeur qui a créé l’outil OiRA particulier. Vous ne devez pas estimer leur niveau de priorité, car leur priorité est automatiquement définie comme «élevée».

Risques prioritaires.

### Risques personnalisés

Quand vous aurez donné votre réponse pour tous les risques sous «Identification + Estimation»/«Évaluation», vous accéderez à la rubrique facultative «Autres risques». Ici, le bouton «Ajouter un risque personnalisé» vous permet de créer vos propres entrées.

Vous pouvez ainsi ajouter des risques présents sur votre lieu de travail et qui ne figurent pas dans l’outil. Ces risques peuvent être entièrement décrits/formulés par vous.

Risques personnalisés.

Le fonctionnement est le même que pour les risques prévus par l’outil OiRA, si ce n’est que vous devez évidemment rédiger votre propre texte. Cet énoncé devrait au moins décrire brièvement une situation de risque ou de problème, mais il peut aussi être plus long. Vous pouvez également télécharger une image pour illustrer une situation donnée.

Comme pour les autres risques, vous devez indiquer si le risque est présent ou non. Cela vous permettra de cocher les risques personnalisés une fois que vous aurez pris les mesures nécessaires, mais conservez-les dans votre évaluation des risques à des fins documentaires.

Vous pouvez ajouter autant de risques personnalisés que vous le souhaitez.

Ajouter un risque personnalisé.

## Plan d’action

À cette étape, vous décidez des mesures que vous voulez mettre en œuvre pour éliminer ou atténuer les risques que vous avez précédemment identifiés.

Remarque: Comme mentionné ci-dessus, le plan d’action est présenté comme une étape distincte dans le menu de gauche ou apparaît sous chaque risque identifié. Dans ce dernier cas, l’étape du menu est appelée «Évaluation» et comprend à la fois les énoncés des risques et un éventail de réponses.

La configuration qui vous est fournie dépend des choix faits par le partenaire national/développeur d’outils OiRA.

### Plan d’action intégré

Plan d’action intégré.

Pour chaque risque, si vous répondez par «non», le module du plan d’action se déroulera sur la page, sous la rubrique «Mesures».

Vous pouvez à la fois choisir dans une liste de mesures proposées par le système et définir vos propres mesures.

### Plan d’action séparé

Lorsque le plan d'action constitue une étape distincte, il est accessible via le menu sur le côté gauche de l’écran.

Cliquez sur le bouton «Créer un plan d’action» pour démarrer votre plan.

À ce niveau, le menu de gauche n’affiche plus que les risques identifiés pour une action ultérieure, car les autres risques ont été cochés comme étant non présents.

Pour chaque risque auquel vous avez répondu «non» au cours du processus d’estimation et pour les risques prioritaires (indépendamment de la réponse positive ou négative), il vous sera demandé de définir des mesures.

Un risque inscrit au plan d'action.

Vous pouvez soit choisir parmi une liste de mesures proposées par le système, soit définir vos propres mesures.

#### Ajouter votre propre mesure

Ajouter une mesure supplémentaire.

Utilisez le bouton «Ajouter une mesure» pour commencer à définir une mesure préventive. Vous devrez:

- décrire l’approche générale qui sera adoptée pour éliminer ou réduire le risque;
- indiquer éventuellement le niveau d’expertise et/ou les exigences nécessaires (par exemple, vous pouvez signaler ici si une formation particulière ou une expertise externe est nécessaire pour faire face à ce risque);
- indiquer qui est responsable de la mise en œuvre;
- définir un budget, s’il y a lieu;
- fixer éventuellement des dates pour le début et la fin prévue de la mise en œuvre de la mesure.

Vous pouvez ajouter autant de mesures que vous le souhaitez.

#### Ajouter des mesures standard

Selon la configuration de l’outil choisie par le partenaire/développeur d’outils OiRA, des mesures prédéfinies sont disponibles pour les risques individuels. Pour choisir une ou plusieurs mesures prédéfinies, cliquez sur le bouton «Sélectionner les mesures standard».

Un menu déroulant s’ouvre et affiche toutes les mesures proposées. Cliquez sur le bouton «Ajouter» pour les mesures que vous souhaitez utiliser.

Les mesures prédéfinies s’affichent alors dans votre plan d’action. La description des mesures est figée, mais les autres champs (responsabilité, budget, dates) peuvent et devraient être remplis par vous.

Ajouter des mesures standard.

Les mesures standard et les mesures que vous avez définies peuvent être supprimées à tout moment.

## Rapport

Après avoir finalisé le plan d’action, vous pouvez générer un rapport.

Si vous souhaitez laisser un commentaire à inclure dans le rapport, saisissez votre texte ici et sauvegardez-le.

Commenter le rapport.

Voir ici pour en savoir plus sur les différents rapports et leur utilisation.

## Statut

Le petit graphique circulaire dans le menu de gauche indique l’avancement du travail accompli.

La section sur le statut vous donne un aperçu du nombre de risques que vous avez identifiés, du nombre de risques identifiés pour lesquels vous avez décidé des mesures et du nombre de risques/énoncés toujours en attente de votre réponse.

La page de Statut.

Cette page vous permet de voir le travail accompli dans chaque module. Cela peut vous aider à repérer les domaines dans lesquels vous devez encore évaluer des risques ou prévoir des mesures pour les risques que vous avez identifiés.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More